summaryrefslogtreecommitdiffstats
path: root/contrib/gcc/flags.h
diff options
context:
space:
mode:
authorobrien <obrien@FreeBSD.org>1999-10-26 08:45:23 +0000
committerobrien <obrien@FreeBSD.org>1999-10-26 08:45:23 +0000
commitbdaadca7c04793148a5c8fd26c85a5278a9676a4 (patch)
treed85126e2009ced1b29f925660af3748fac186af2 /contrib/gcc/flags.h
parent8db9511c0445b99c8147d1eac31be55c75be0618 (diff)
downloadFreeBSD-src-bdaadca7c04793148a5c8fd26c85a5278a9676a4.zip
FreeBSD-src-bdaadca7c04793148a5c8fd26c85a5278a9676a4.tar.gz
Merge our changes - this brings rev 1.2 (-fformat-extensions)
into GCC 2.95.1.
Diffstat (limited to 'contrib/gcc/flags.h')
-rw-r--r--contrib/gcc/flags.h61
1 files changed, 53 insertions, 8 deletions
diff --git a/contrib/gcc/flags.h b/contrib/gcc/flags.h
index 74445f6..a7c1b7e 100644
--- a/contrib/gcc/flags.h
+++ b/contrib/gcc/flags.h
@@ -1,5 +1,5 @@
/* Compilation switch flag definitions for GNU CC.
- Copyright (C) 1987, 88, 94, 95, 96, 97, 1998 Free Software Foundation, Inc.
+ Copyright (C) 1987, 88, 94-98, 1999 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -18,6 +18,8 @@ along with GNU CC; see the file COPYING. If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
+/* $FreeBSD$ */
+
/* Name of the input .c file being compiled. */
extern char *main_input_filename;
@@ -280,10 +282,14 @@ extern int flag_no_peephole;
extern int flag_volatile;
/* Nonzero means treat all global and extern variables as global. */
extern int flag_volatile_global;
+/* Nonzero means treat all static variables as volatile. */
+
+extern int flag_volatile_static;
+
/* Nonzero allows GCC to violate some IEEE or ANSI rules regarding math
operations in the interest of optimization. For example it allows
GCC to assume arguments to sqrt are nonnegative numbers, allowing
@@ -291,14 +297,20 @@ extern int flag_volatile_global;
extern int flag_fast_math;
-/* Nonzero means to run loop optimizations twice. */
+/* Nonzero means the front end generally wants `errno' maintained by math
+ operations, like built-in SQRT, unless overridden by flag_fast_math. */
-extern int flag_rerun_loop_opt;
+extern int flag_errno_math;
+
+/* 0 means straightforward implementation of complex divide acceptable.
+ 1 means wide ranges of inputs must work for complex divide.
+ 2 means C9X-like requirements for complex divide (not yet implemented). */
-/* Nonzero means to assume that a structure or an array reference at
- a varying address cannot alias a scalar at a fixed address. */
+extern int flag_complex_divide_method;
-extern int flag_structure_noalias;
+/* Nonzero means to run loop optimizations twice. */
+
+extern int flag_rerun_loop_opt;
/* Nonzero means make functions that look like good inline candidates
go inline. */
@@ -354,17 +366,22 @@ extern int flag_schedule_interblock;
extern int flag_schedule_speculative;
extern int flag_schedule_speculative_load;
extern int flag_schedule_speculative_load_dangerous;
+#endif /* HAIFA */
/* flag_on_branch_count_reg means try to replace add-1,compare,branch tupple
by a cheaper branch, on a count register. */
extern int flag_branch_on_count_reg;
-#endif /* HAIFA */
/* Nonzero means put things in delayed-branch slots if supported. */
extern int flag_delayed_branch;
+/* Nonzero means suppress output of instruction numbers and line number
+ notes in debugging dumps. */
+
+extern int flag_dump_unnumbered;
+
/* Nonzero means pretend it is OK to examine bits of target floats,
even if that isn't true. The resulting code will have incorrect constants,
but the same series of instructions that the native compiler would make. */
@@ -407,6 +424,10 @@ extern int flag_inhibit_size_directive;
extern int flag_function_sections;
+/* ... and similar for data. */
+
+extern int flag_data_sections;
+
/* -fverbose-asm causes extra commentary information to be produced in
the generated assembly code (to make it more readable). This option
is generally only of use to those who actually need to read the
@@ -453,6 +474,9 @@ extern int flag_stack_check;
/* Do the full regmove optimization pass. */
extern int flag_regmove;
+
+/* Instrument functions with calls at entry and exit, for profiling. */
+extern int flag_instrument_function_entry_exit;
/* Other basic status info about current function. */
@@ -499,3 +523,24 @@ extern int current_function_is_thunk;
/* Value of the -G xx switch, and whether it was passed or not. */
extern int g_switch_value;
extern int g_switch_set;
+
+/* Value of the -finline-limit flag. */
+
+extern int inline_max_insns;
+
+/* Nonzero if we dump in VCG format, not plain text. */
+extern int dump_for_graph;
+
+/* Selection of the graph form. */
+enum graph_dump_types
+{
+ no_graph = 0,
+ vcg
+};
+extern enum graph_dump_types graph_dump_format;
+
+/* Nonzero means ignore `#ident' directives. 0 means handle them.
+ On SVR4 targets, it also controls whether or not to emit a
+ string identifying the compiler. */
+
+extern int flag_no_ident;
OpenPOWER on IntegriCloud
@@ -280,10 +282,14 @@ extern int flag_no_peephole;
extern int flag_volatile;
-/* Nonzero means treat all global and extern variables as global. */
+/* Nonzero means treat all global and extern variables as volatile. */
extern int flag_volatile_global;